California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 014 - ELECTIONS: OPEN PRIMARIES. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1317016 | PROTECT THE DEMOCRATIC PARTY - SAY NO TO THE OPEN PRIMARY | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1322507 | YES ON 14 - CALIFORNIANS FOR AN OPEN PRIMARY WITH MAJOR FUNDING FROM GOVERNOR SCHWARZENEGGER'S CALIFORNIA DREAM TEAM, A BALLOT MEASURE COMMITTEE | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1316056 | SAVE VOTER CHOICE, NO ON 14 WITH MAJOR FUNDING BY JEFF DENHAM FOR STATE SENATE | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1327271 | NO ON 14 PROTECT VOTER CHOICE. SPONSORED BY TEACHERS, SCHOOL EMPLOYEES, CONSUMER ATTORNEY AND LABOR ORGANIZATIONSS | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1327278 | TOBIN'S STOP TOP TWO. ORG - VOTE NO ON PROPOSITION 14, CHRISTINA | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1327197 | NO ON PROP. 14, PRESERVE VOTER CHOICE | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1324981 | SWANSON'S BALLOT MEASURE COMMITTEE TO OPPOSE PROP. 14 - OPEN PRIMARIES, ASSEMBLYMEMBER SANDRE | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1333781 | SILICON VALLEY LEADERSHIP GROUP IN SUPPORT OF PROPOSITION 14 | SUPPORT